Announcing Caterva2 2025.12.3
==============================

Caterva2 is a high-performance storage and computation system for
Blosc2 and HDF5 data repositories.

This is a minor release, which introduces certain minor API breaking changes (``client.lazyexpr`` has disappeared, ``upload`` signature has changed slightly).

For more info, you can have a look at the release notes in:

https://github.com/ironArray/Caterva2/releases

Ready for serious data sharing?  Visit the Caterva2 website:

https://ironarray.io/caterva2

## What is it?

Caterva2 is a server written in Python meant for sharing Blosc2 and HDF5
datasets.  There are several interfaces to Caterva2, including a web GUI,
a REST API, a Python API, and a command-line client. With Caterva2, you can
easily share your datasets with your colleagues, or even the public.

Caterva2 is distributed using the AGPL license, see
https://github.com/ironArray/Caterva2/blob/main/LICENSE.txt
for details.

## Follow us

We send announcements on Mastodon: https://mastodon.social/@ironArray,
and LinkedIn: https://www.linkedin.com/company/77649425/admin/feed/posts/

You can contact us at: https://ironarray.io


-- The ironArray Team
   Make compression better
